==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/CSIVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CSIVolumeSourceFluent<A extends CSIVolumeSourceFluent<A>> extends Fluent<A> {


    public String getDriver();
    public A withDriver(String driver);
    public Boolean hasDriver();
    public A withNewDriver(StringBuilder arg1);
    public A withNewDriver(int[] arg1,int arg2,int arg3);
    public A withNewDriver(char[] arg1);
    public A withNewDriver(StringBuffer arg1);
    public A withNewDriver(byte[] arg1,int arg2);
    public A withNewDriver(byte[] arg1);
    public A withNewDriver(char[] arg1,int arg2,int arg3);
    public A withNewDriver(byte[] arg1,int arg2,int arg3);
    public A withNewDriver(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDriver(String arg1);
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    
/**
 * This method has been deprecated, please use method buildNodePublishSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public LocalObjectReference getNodePublishSecretRef();
    public LocalObjectReference buildNodePublishSecretRef();
    public A withNodePublishSecretRef(LocalObjectReference nodePublishSecretRef);
    public Boolean hasNodePublishSecretRef();
    public A withNewNodePublishSecretRef(String name);
    public CSIVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
    public CSIVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(LocalObjectReference item);
    public CSIVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
    public CSIVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
    public CSIVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(LocalObjectReference item);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public A addToVolumeAttributes(String key,String value);
    public A addToVolumeAttributes(Map<String,String> map);
    public A removeFromVolumeAttributes(String key);
    public A removeFromVolumeAttributes(Map<String,String> map);
    public Map<String,String> getVolumeAttributes();
    public <K extends Object,V extends Object>A withVolumeAttributes(Map<String,String> volumeAttributes);
    public Boolean hasVolumeAttributes();
    public interface NodePublishSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<CSIVolumeSourceFluent.NodePublishSecretRefNested<N>> {

            public N and();
            public N endNodePublishSecretRef();    }


}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/CSIVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CSIVolumeSourceFluent<A extends CSIVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getDriver();
    public A withDriver(String driver);
    public Boolean hasDriver();
    public A withNewDriver(StringBuilder arg1);
    public A withNewDriver(int[] arg1,int arg2,int arg3);
    public A withNewDriver(char[] arg1);
    public A withNewDriver(StringBuffer arg1);
    public A withNewDriver(byte[] arg1,int arg2);
    public A withNewDriver(byte[] arg1);
    public A withNewDriver(char[] arg1,int arg2,int arg3);
    public A withNewDriver(byte[] arg1,int arg2,int arg3);
    public A withNewDriver(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDriver(String arg1);
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    
/**
 * This method has been deprecated, please use method buildNodePublishSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public LocalObjectReference getNodePublishSecretRef();
    public LocalObjectReference buildNodePublishSecretRef();
    public A withNodePublishSecretRef(LocalObjectReference nodePublishSecretRef);
    public Boolean hasNodePublishSecretRef();
    public A withNewNodePublishSecretRef(String name);
    public io.fabric8.kubernetes.api.model.CSIVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
    public io.fabric8.kubernetes.api.model.CSIVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(LocalObjectReference item);
    public io.fabric8.kubernetes.api.model.CSIVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
    public io.fabric8.kubernetes.api.model.CSIVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
    public io.fabric8.kubernetes.api.model.CSIVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(LocalObjectReference item);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public A addToVolumeAttributes(String key,String value);
    public A addToVolumeAttributes(java.util.Map<String,String> map);
    public A removeFromVolumeAttributes(String key);
    public A removeFromVolumeAttributes(java.util.Map<String,String> map);
    public java.util.Map<String,String> getVolumeAttributes();
    public <K extends Object,V extends Object>A withVolumeAttributes(java.util.Map<String,String> volumeAttributes);
    public Boolean hasVolumeAttributes();
    public interface NodePublishSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<io.fabric8.kubernetes.api.model.CSIVolumeSourceFluent.NodePublishSecretRefNested<N>> {

            public N and();
            public N endNodePublishSecretRef();    }


}
